Crate librojo

Crate librojo 

Modules

cli
Defines Rojo’s CLI through clap types.
web_api
Defines all the structs needed to interact with the Rojo Serve API. This is useful for tests to be able to use the same data structures as the implementation.

Structs

FsSnapshot
A simple representation of a subsection of a file system.
InstanceContext
InstanceMetadata
Rojo-specific metadata that can be associated with an instance or a snapshot of an instance.
InstanceSnapshot
A lightweight description of what an instance should look like.
InstanceWithMeta
RojoTree’s equivalent of &'a Instance.
InstanceWithMetaMut
RojoTree’s equivalent of &'a mut Instance.
OptionalPathNode
Project
Contains all of the configuration for a Rojo-managed project.
ProjectError
Error type returned by any function that handles projects.
ProjectNode
Describes an instance and its descendants in a project.
RojoDescendants
RojoRef
RojoTree
An expanded variant of rbx_dom_weak’s WeakDom that tracks additional metadata per instance that’s Rojo-specific.
SessionId
A randomly generated ID generated by Rojo during a serve session.
SyncbackData
SyncbackSnapshot

Enums

Middleware
Represents a possible ‘transformer’ used by Rojo to turn a file system item into a Roblox Instance. Missing from this list is metadata. This is deliberate, as metadata is not a snapshot middleware.
PathNode
Describes a path that is either optional or required
ScriptType

Constants

REF_ID_ATTRIBUTE_NAME
REF_POINTER_ATTRIBUTE_PREFIX

Statics

DEFAULT_PROJECT_NAMES
Represents ‘default’ project names that act as init files

Functions

snapshot_from_vfs
Returns an InstanceSnapshot for the provided path. This will inspect the path and find the appropriate middleware for it, taking user-written rules into account. Then, it will attempt to convert the path into an InstanceSnapshot using that middleware.
syncback_loop