Module cli

Module cli 

Defines Rojo’s CLI through clap types.

Structs

BuildCommand
Generates a model or place file from the Rojo project.
ColorChoiceParseError
DocCommand
Open Rojo’s documentation in your browser.
FmtProjectCommand
Reformat a Rojo project using the standard JSON formatting rules.
GlobalOptions
InitCommand
Initializes a new Rojo project.
Options
Command line options that Rojo accepts, defined using the clap crate.
PluginCommand
Install Rojo’s plugin.
ServeCommand
Expose a Rojo project to the Rojo Studio plugin.
SourcemapCommand
Generates a sourcemap file from the Rojo project.
SyncbackCommand
Performs ‘syncback’ for the provided project, using the input file given.
UploadCommand
Builds the project and uploads it to Roblox.

Enums

ColorChoice
InitKind
The templates we support for initializing a Rojo project.
PluginSubcommand
Manages Rojo’s Roblox Studio plugin.
Subcommand