pub enum InitKind {
Place,
Model,
}Expand description
The templates we support for initializing a Rojo project.
Variants
Place
A place that contains a baseplate.
Model
An empty model, suitable for a library or plugin.