Struct librojo::cli::BuildCommand
source · [−]Expand description
Generates a model or place file from the Rojo project.
Fields
project: PathBufPath to the project to serve. Defaults to the current directory.
output: PathBufWhere to output the result.
Should end in .rbxm, .rbxl, .rbxmx, or .rbxlx.
watch: boolWhether to automatically rebuild when any input files change.
Implementations