Struct librojo::cli::SourcemapCommand
source · [−]pub struct SourcemapCommand {
pub project: PathBuf,
pub output: Option<PathBuf>,
pub include_non_scripts: bool,
}Expand description
Generates a sourcemap file from the Rojo project.
Fields
project: PathBufPath to the project to use for the sourcemap. Defaults to the current directory.
output: Option<PathBuf>Where to output the sourcemap. Omit this to use stdout instead of writing to a file.
Should end in .json.
include_non_scripts: boolIf non-script files should be included or not. Defaults to false.
Implementations