pub struct SyncbackCommand {
pub project: PathBuf,
pub input: PathBuf,
pub list: bool,
pub dry_run: bool,
pub non_interactive: bool,
}Expand description
Performs ‘syncback’ for the provided project, using the input file
given.
Syncback exists to convert Roblox files into a Rojo project automatically. It uses the project.json file provided to traverse the Roblox file passed as to serialize Instances to the file system in a format that Rojo understands.
To ease programmatic use, this command pipes all normal output to stderr.
Fields
project: PathBufPath to the project to sync back to.
input: PathBufPath to the Roblox file to pull Instances from.
list: boolIf provided, a list all of the files and directories that will be added or removed is emitted into stdout.
dry_run: boolIf provided, syncback will not actually write anything to the file system. The command will otherwise run normally.
non_interactive: boolIf provided, the prompt for writing to the file system is skipped.
Implementations
Sourceimpl SyncbackCommand
impl SyncbackCommand
pub fn run(&self, global: GlobalOptions) -> Result<()>