pub enum Middleware {
Show 24 variants
Csv,
JsonModel,
Json,
ServerScript,
ClientScript,
ModuleScript,
PluginScript,
LegacyClientScript,
LegacyServerScript,
RunContextServerScript,
RunContextClientScript,
Project,
Rbxm,
Rbxmx,
Toml,
Text,
Yaml,
Ignore,
Dir,
ServerScriptDir,
ClientScriptDir,
PluginScriptDir,
ModuleScriptDir,
CsvDir,
}Expand description
Represents a possible ‘transformer’ used by Rojo to turn a file system item into a Roblox Instance. Missing from this list is metadata. This is deliberate, as metadata is not a snapshot middleware.
Directories cannot be used for sync rules so they’re ignored by Serde.
Variants
Csv
JsonModel
Json
ServerScript
ClientScript
ModuleScript
PluginScript
LegacyClientScript
LegacyServerScript
RunContextServerScript
RunContextClientScript
Project
Rbxm
Rbxmx
Toml
Text
Yaml
Ignore
Dir
ServerScriptDir
ClientScriptDir
PluginScriptDir
ModuleScriptDir
CsvDir
Implementations
Sourceimpl Middleware
impl Middleware
Sourcepub fn syncback<'sync>(
&self,
snapshot: &SyncbackSnapshot<'sync>,
) -> Result<SyncbackReturn<'sync>>
pub fn syncback<'sync>( &self, snapshot: &SyncbackSnapshot<'sync>, ) -> Result<SyncbackReturn<'sync>>
Runs the syncback mechanism for the provided middleware given a SyncbackSnapshot.
Sourcepub fn is_dir(&self) -> bool
pub fn is_dir(&self) -> bool
Returns whether this particular middleware would become a directory.
Sourcepub fn handles_own_properties(&self) -> bool
pub fn handles_own_properties(&self) -> bool
Returns whether this particular middleware sets its own properties.
This applies to things like JsonModel and Project, since they
set properties without needing a meta.json file.
It does not cover middleware like ServerScript or Csv because they
need a meta.json file to set properties that aren’t their designated
‘special’ properties.