pub struct InstanceContext {
pub path_ignore_rules: Arc<Vec<PathIgnoreRule>>,
pub emit_legacy_scripts: bool,
pub sync_rules: Vec<SyncRule>,
}Fields
path_ignore_rules: Arc<Vec<PathIgnoreRule>>emit_legacy_scripts: boolsync_rules: Vec<SyncRule>Implementations
Sourceimpl InstanceContext
impl InstanceContext
pub fn new() -> Self
pub fn with_emit_legacy_scripts(emit_legacy_scripts: Option<bool>) -> Self
Sourcepub fn add_path_ignore_rules<I>(&mut self, new_rules: I)
pub fn add_path_ignore_rules<I>(&mut self, new_rules: I)
Extend the list of ignore rules in the context with the given new rules.
Sourcepub fn add_sync_rules<I>(&mut self, new_rules: I)where
I: IntoIterator<Item = SyncRule>,
pub fn add_sync_rules<I>(&mut self, new_rules: I)where
I: IntoIterator<Item = SyncRule>,
Extend the list of syncing rules in the context with the given new rules.
Sourcepub fn clear_sync_rules(&mut self)
pub fn clear_sync_rules(&mut self)
Clears all sync rules for this InstanceContext
pub fn set_emit_legacy_scripts(&mut self, emit_legacy_scripts: bool)
Sourcepub fn get_user_sync_rule(&self, path: &Path) -> Option<&SyncRule>
pub fn get_user_sync_rule(&self, path: &Path) -> Option<&SyncRule>
Returns the middleware specified by the first sync rule that matches the provided path. This does not handle default syncing rules.