pub struct InstanceSnapshot {
pub snapshot_id: Ref,
pub metadata: InstanceMetadata,
pub name: Cow<'static, str>,
pub class_name: Ustr,
pub properties: UstrMap<Variant>,
pub children: Vec<InstanceSnapshot>,
}Expand description
A lightweight description of what an instance should look like.
Fields
snapshot_id: RefA temporary ID applied to the snapshot that’s used for Ref properties.
metadata: InstanceMetadataRojo-specific metadata associated with the instance.
name: Cow<'static, str>Correpsonds to the Name property of the instance.
class_name: UstrCorresponds to the ClassName property of the instance.
properties: UstrMap<Variant>All other properties of the instance, weakly-typed.
children: Vec<InstanceSnapshot>The children of the instance represented as more snapshots.
Order is relevant for Roblox instances!
Implementations
Sourceimpl InstanceSnapshot
impl InstanceSnapshot
pub fn new() -> Self
pub fn name(self, name: impl Into<String>) -> Self
pub fn class_name<S: Into<Ustr>>(self, class_name: S) -> Self
pub fn property<K, V>(self, key: K, value: V) -> Self
pub fn properties(self, properties: impl Into<UstrMap<Variant>>) -> Self
pub fn children(self, children: impl Into<Vec<Self>>) -> Self
pub fn snapshot_id(self, snapshot_id: Ref) -> Self
pub fn metadata(self, metadata: impl Into<InstanceMetadata>) -> Self
pub fn from_tree(tree: WeakDom, id: Ref) -> Self