RojoTree

Struct RojoTree 

pub struct RojoTree { /* private fields */ }
An expanded variant of rbx_dom_weak’s WeakDom that tracks additional metadata per instance that’s Rojo-specific.

This tree is also optimized for doing fast incremental updates and patches.

Implementations

Source

impl RojoTree

pub fn new(snapshot: InstanceSnapshot) -> RojoTree

pub fn inner(&self) -> &WeakDom

pub fn get_root_id(&self) -> Ref

pub fn root(&self) -> InstanceWithMeta<'_>

Returns the root Instance of this tree.

pub fn get_instance(&self, id: Ref) -> Option<InstanceWithMeta<'_>>

pub fn get_instance_mut(&mut self, id: Ref) -> Option<InstanceWithMetaMut<'_>>

pub fn insert_instance( &mut self, parent_ref: Ref, snapshot: InstanceSnapshot, ) -> Ref

pub fn remove(&mut self, id: Ref)

pub fn update_metadata(&mut self, id: Ref, metadata: InstanceMetadata)

Replaces the metadata associated with the given instance ID.

pub fn descendants(&self, id: Ref) -> RojoDescendants<'_>

pub fn get_ids_at_path(&self, path: &Path) -> &[Ref]

pub fn get_metadata(&self, id: Ref) -> Option<&InstanceMetadata>

pub fn get_specified_id(&self, specified: &RojoRef) -> Option<Ref>

Get the backing Ref of the given RojoRef. If the RojoRef maps to exactly one Ref, this method returns Some. Otherwise, it returns None.

pub fn set_specified_id(&mut self, id: Ref, specified: RojoRef)