SyncbackSnapshot

Struct SyncbackSnapshot 

pub struct SyncbackSnapshot<'sync> {
    pub data: SyncbackData<'sync>,
    pub old: Option<Ref>,
    pub new: Ref,
    pub path: PathBuf,
    pub middleware: Option<Middleware>,
}

Fields

data: SyncbackData<'sync>old: Option<Ref>new: Refpath: PathBufmiddleware: Option<Middleware>

Implementations

Source

impl<'sync> SyncbackSnapshot<'sync>

pub fn with_joined_path( &self, new_ref: Ref, old_ref: Option<Ref>, ) -> Result<Self>

Constructs a SyncbackSnapshot from the provided refs while inheriting this snapshot’s path and data. This should be used for directories.

pub fn with_base_path( &self, base_path: &Path, new_ref: Ref, old_ref: Option<Ref>, ) -> Result<Self>

Constructs a SyncbackSnapshot from the provided refs and a base path, while inheriting this snapshot’s data.

The actual path of the snapshot is made by getting a file name for the snapshot and then appending it to the provided base path.

pub fn with_new_path( &self, path: PathBuf, new_ref: Ref, old_ref: Option<Ref>, ) -> Self

Constructs a SyncbackSnapshot with the provided path and refs while inheriting the data of the this snapshot.

pub fn middleware(self, middleware: Middleware) -> Self

Allows a middleware to be ‘forced’ onto a SyncbackSnapshot to override the attempts to derive it.

pub fn get_path_filtered_properties( &self, new_ref: Ref, ) -> Option<UstrMap<&'sync Variant>>

Returns a map of properties for an Instance from the ‘new’ tree with filtering done to avoid noise. This method filters out properties that are not meant to be present in Instances that are represented specially by a path, like LocalScript.Source and StringValue.Value.

This method is not necessary or desired for blobs like Rbxm or non-path middlewares like JsonModel.

pub fn get_new_inst_path(&self, referent: Ref) -> String

Returns a path to the provided Instance in the new DOM. This path is where you would look for the object in Roblox Studio.

pub fn get_old_inst_path(&self, referent: Ref) -> String

Returns a path to the provided Instance in the old DOM. This path is where you would look for the object in Roblox Studio.

pub fn get_old_instance(&self, referent: Ref) -> Option<InstanceWithMeta<'sync>>

Returns an Instance from the old tree with the provided referent, if it exists.

pub fn get_new_instance(&self, referent: Ref) -> Option<&'sync Instance>

Returns an Instance from the new tree with the provided referent, if it exists.

pub fn old_inst(&self) -> Option<InstanceWithMeta<'sync>>

The ‘old’ Instance this snapshot is for, if it exists.

pub fn new_inst(&self) -> &'sync Instance

The ‘new’ Instance this snapshot is for.

pub fn project(&self) -> &'sync Project

Returns the root Project that was used to make this snapshot.

pub fn vfs(&self) -> &'sync Vfs

Returns the underlying VFS being used for syncback.

pub fn new_tree(&self) -> &'sync WeakDom

Returns the WeakDom used for the ‘new’ tree.

pub fn old_tree(&self) -> &'sync WeakDom

Returns the WeakDom used for the ‘old’ tree.

pub fn ignore_props(&self) -> Option<&IndexMap<Ustr, Vec<Ustr>>>

Returns user-specified property ignore rules.

pub fn ignore_tree(&self) -> Option<&[String]>

Returns user-specified ignore tree.