Module web_api

Module web_api 

Defines all the structs needed to interact with the Rojo Serve API. This is useful for tests to be able to use the same data structures as the implementation.

Structs

ErrorResponse
General response type returned from all Rojo routes
Instance
InstanceMetadata
InstanceUpdate
MessagesPacket
Body content for messages packet type
OpenResponse
Response body from /api/open/{id}
ReadResponse
Response body from /api/read/{id}
RefPatchRequest
RefPatchResponse
SerializeRequest
SerializeResponse
ServerInfoResponse
Response body from /api/rojo
SocketPacket
Message content from /api/socket
SubscribeMessage
Message returned by Rojo API when a change has occurred.
WriteRequest
WriteResponse

Enums

ErrorResponseKind
SocketPacketBody
Body content for different packet types
SocketPacketType
Packet type enum for different websocket message types

Constants

PROTOCOL_VERSION
Current protocol version, which is required to match.