Defines all the structs needed to interact with the Rojo Serve API. This is
useful for tests to be able to use the same data structures as the
implementation.
Represents a possible ‘transformer’ used by Rojo to turn a file system
item into a Roblox Instance. Missing from this list is metadata.
This is deliberate, as metadata is not a snapshot middleware.
Returns an InstanceSnapshot for the provided path.
This will inspect the path and find the appropriate middleware for it,
taking user-written rules into account. Then, it will attempt to convert
the path into an InstanceSnapshot using that middleware.