FsSnapshot

Struct FsSnapshot 

pub struct FsSnapshot { /* private fields */ }
A simple representation of a subsection of a file system.

Implementations

Source

impl FsSnapshot

pub fn new() -> Self

Creates a new FsSnapshot.

pub fn with_added_file<P: AsRef<Path>>(self, path: P, data: Vec<u8>) -> Self

Adds the given path to the FsSnapshot as a file with the given contents, then returns it.

pub fn with_added_dir<P: AsRef<Path>>(self, path: P) -> Self

Adds the given path to the FsSnapshot as a file with the given then returns it.

pub fn merge(&mut self, other: Self)

Merges two FsSnapshots together.

pub fn merge_with_filter<F>(&mut self, other: Self, predicate: F)
where F: FnMut(&Path) -> bool,

Merges two FsSnapshots together, with a filter applied to the paths.

pub fn add_file<P: AsRef<Path>>(&mut self, path: P, data: Vec<u8>)

Adds the provided path as a file with the given contents.

pub fn add_dir<P: AsRef<Path>>(&mut self, path: P)

Adds the provided path as a directory.

pub fn remove_file<P: AsRef<Path>>(&mut self, path: P)

Removes the provided path, as a file.

pub fn remove_dir<P: AsRef<Path>>(&mut self, path: P)

Removes the provided path, as a directory.

pub fn write_to_vfs<P: AsRef<Path>>(&self, base: P, vfs: &Vfs) -> Result<()>

Writes the FsSnapshot to the provided VFS, using the provided base as a root for the other paths in the FsSnapshot.

This includes removals, but makes no effort to minimize work done.

pub fn is_empty(&self) -> bool

Returns whether this FsSnapshot is empty or not.

pub fn added_paths(&self) -> Vec<&Path>

Returns a list of paths that would be added by this FsSnapshot.

pub fn removed_paths(&self) -> Vec<&Path>

Returns a list of paths that would be removed by this FsSnapshot.

pub fn added_files(&self) -> Vec<&Path>

Returns a list of file paths that would be added by this FsSnapshot

pub fn added_dirs(&self) -> Vec<&Path>

Returns a list of directory paths that would be added by this FsSnapshot

pub fn removed_files(&self) -> Vec<&Path>

Returns a list of file paths that would be removed by this FsSnapshot

pub fn removed_dirs(&self) -> Vec<&Path>

Returns a list of directory paths that would be removed by this FsSnapshot