Defines all the structs needed to interact with the Rojo Serve API. This is useful for tests to be able to use the same data structures as the implementation.
Structs
- Error
Response - General response type returned from all Rojo routes
- Instance
- Instance
Metadata - Instance
Update - Messages
Packet - Body content for messages packet type
- Open
Response - Response body from /api/open/{id}
- Read
Response - Response body from /api/read/{id}
- RefPatch
Request - RefPatch
Response - Serialize
Request - Serialize
Response - Server
Info Response - Response body from /api/rojo
- Socket
Packet - Message content from /api/socket
- Subscribe
Message - Message returned by Rojo API when a change has occurred.
- Write
Request - Write
Response
Enums
- Error
Response Kind - Socket
Packet Body - Body content for different packet types
- Socket
Packet Type - Packet type enum for different websocket message types
Constants
- PROTOCOL_
VERSION - Current protocol version, which is required to match.